from django import forms
from django.contrib.auth.forms import UserCreationForm, AuthenticationForm
from .models import User
import uuid
from datetime import datetime


class SignupForm(UserCreationForm):
  
    country = forms.CharField(
        max_length=20,
        required=True,
        widget=forms.TextInput(attrs={'placeholder': 'Country'})
    )
    next_of_kin = forms.CharField(
        max_length=20,
        required=True,
        widget=forms.TextInput(attrs={'placeholder': 'Next of Kin'})
    )
    security_validation_phrase = forms.CharField(
        max_length=20,
        required=True,
        widget=forms.TextInput(attrs={'placeholder': 'Security Validation Phrase'})
    )
    address = forms.CharField(
        max_length=40,
        required=True,
        widget=forms.TextInput(attrs={'placeholder': 'Address'})
    )
    authentication_pin = forms.IntegerField(
        required=True,
        widget=forms.NumberInput(attrs={'placeholder': 'Authentication PIN'})
    )
    state_of_origin = forms.CharField(
        max_length=100,
        required=True,
        widget=forms.TextInput(attrs={'placeholder': 'State of Origin'})
    )
    phone_number = forms.CharField(
        max_length=30,
        required=True,
        widget=forms.TextInput(attrs={'placeholder': 'Phone Number'})
    )

    class Meta:
        model = User
        fields = (
            "username",
            "email",
            "password1",
            "password2",
            "first_name",
            "last_name",
            
            "country",
            "next_of_kin",
            "security_validation_phrase",
            "address",
            "authentication_pin",
            "state_of_origin",
            "phone_number",
        )

    username = forms.CharField(
        widget=forms.TextInput(
            attrs={"placeholder": "Input Personal Username"}
        )
    )

    first_name = forms.CharField(
        required=True,
        widget=forms.TextInput(
            attrs={"placeholder": "First Name"}
        )
    )

    last_name = forms.CharField(
        required=True,
        widget=forms.TextInput(
            attrs={"placeholder": "Last Name"}
        )
    )

    email = forms.CharField(
        required=True,
        widget=forms.EmailInput(
            attrs={"placeholder": "Email"}
        )
    )

    password1 = forms.CharField(
        required=True,
        widget=forms.PasswordInput(
            attrs={"placeholder": "Password"}
        )
    )
    password2 = forms.CharField(
        required=True,
        widget=forms.PasswordInput(
            attrs={"placeholder": "Confirm Password"}
        )
    )


class LoginForm(AuthenticationForm):
    username = forms.CharField(widget=forms.TextInput)

    password = forms.CharField(widget=forms.PasswordInput)



class TransferForm(forms.Form):
    bank_name = forms.CharField(label='Bank_Name')
    account_name = forms.CharField(label='Account_Name')
    routing_number = forms.CharField(label='Routing_Number')
    amount = forms.DecimalField(label='Amount')
    account_number = forms.CharField(label='Account_Number')
    authentication_pin = forms.IntegerField(label='Authentication_PIN')
    security_validation_phrase = forms.CharField(label="Security Validation Phrase")
    description = forms.CharField(label="description")
    
    

    
class DepositForm(forms.Form):
    bank_name = forms.CharField(label='Bank_Name')
    account_name = forms.CharField(label='Account_Name')
    routing_number = forms.CharField(label='Routing_Number')
    amount = forms.DecimalField(label='Amount')
    account_number = forms.CharField(label='Account_Number')
    description = forms.CharField(label="description")
    
class ActivationForm(forms.Form):
    activation_code = forms.CharField(label='', max_length=100, widget=forms.TextInput(attrs={'class': 'activation-input', 'placeholder': 'Activation Code'}))

    